==> pyrogramv1-1.4.16-py3-none-any.whl: pyrogramv1/raw/base/auth/sent_code_type.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogramv1 import raw
from pyrogramv1.raw.core import TLObject

SentCodeType = Union[raw.types.auth.SentCodeTypeApp, raw.types.auth.SentCodeTypeCall, raw.types.auth.SentCodeTypeFlashCall, raw.types.auth.SentCodeTypeMissedCall, raw.types.auth.SentCodeTypeSms]


# noinspection PyRedeclaration
class SentCodeType:  # type: ignore
    """This base type has 5 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`auth.SentCodeTypeApp <pyrogramv1.raw.types.auth.SentCodeTypeApp>`
            - :obj:`auth.SentCodeTypeCall <pyrogramv1.raw.types.auth.SentCodeTypeCall>`
            - :obj:`auth.SentCodeTypeFlashCall <pyrogramv1.raw.types.auth.SentCodeTypeFlashCall>`
            - :obj:`auth.SentCodeTypeMissedCall <pyrogramv1.raw.types.auth.SentCodeTypeMissedCall>`
            - :obj:`auth.SentCodeTypeSms <pyrogramv1.raw.types.auth.SentCodeTypeSms>`
    """

    QUALNAME = "pyrogramv1.raw.base.auth.SentCodeType"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/sent-code-type")

==> pyrogramv1-1.4.17-py3-none-any.whl: pyrogramv1/raw/base/auth/sent_code_type.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogramv1 import raw
from pyrogramv1.raw.core import TLObject

SentCodeType = Union[raw.types.auth.SentCodeTypeApp, raw.types.auth.SentCodeTypeCall, raw.types.auth.SentCodeTypeEmailCode, raw.types.auth.SentCodeTypeFirebaseSms, raw.types.auth.SentCodeTypeFlashCall, raw.types.auth.SentCodeTypeFragmentSms, raw.types.auth.SentCodeTypeMissedCall, raw.types.auth.SentCodeTypeSetUpEmailRequired, raw.types.auth.SentCodeTypeSms]


# noinspection PyRedeclaration
class SentCodeType:  # type: ignore
    """This base type has 9 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`auth.SentCodeTypeApp <pyrogramv1.raw.types.auth.SentCodeTypeApp>`
            - :obj:`auth.SentCodeTypeCall <pyrogramv1.raw.types.auth.SentCodeTypeCall>`
            - :obj:`auth.SentCodeTypeEmailCode <pyrogramv1.raw.types.auth.SentCodeTypeEmailCode>`
            - :obj:`auth.SentCodeTypeFirebaseSms <pyrogramv1.raw.types.auth.SentCodeTypeFirebaseSms>`
            - :obj:`auth.SentCodeTypeFlashCall <pyrogramv1.raw.types.auth.SentCodeTypeFlashCall>`
            - :obj:`auth.SentCodeTypeFragmentSms <pyrogramv1.raw.types.auth.SentCodeTypeFragmentSms>`
            - :obj:`auth.SentCodeTypeMissedCall <pyrogramv1.raw.types.auth.SentCodeTypeMissedCall>`
            - :obj:`auth.SentCodeTypeSetUpEmailRequired <pyrogramv1.raw.types.auth.SentCodeTypeSetUpEmailRequired>`
            - :obj:`auth.SentCodeTypeSms <pyrogramv1.raw.types.auth.SentCodeTypeSms>`
    """

    QUALNAME = "pyrogramv1.raw.base.auth.SentCodeType"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/sent-code-type")
